﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using asprise_imaging_api;

namespace asprise_imaging_api
{
    /// <summary>
    /// Demo related code.
    /// </summary>
    public class DemoCode
    {
        public static void scanToJpeg()
        {
            Result result = new AspriseImaging().Scan(new Request()
                .SetTwainCap(TwainConstants.ICAP_PIXELTYPE, TwainConstants.TWPT_RGB)
                .SetTwainCap(TwainConstants.ICAP_SUPPORTEDSIZES, TwainConstants.TWSS_USLETTER)
                .SetPromptScanMore(true)
                .AddOutputItem(new RequestOutputItem(AspriseImaging.OUTPUT_SAVE, AspriseImaging.FORMAT_JPG).SetSavePath(".\\${TMS}${EXT}")), 
            "select", true, true);

            List<string> files = result == null ? null : result.GetImageFiles();
            Console.WriteLine("Scanned: " + string.Join(", ", files == null ? new string[0] : files.ToArray()));
        }

        public static void scanToJpegJson()
        {
            Result result = new AspriseImaging().Scan("{" +
                "  \"twain_cap_setting\" : {" +
                "    \"ICAP_PIXEXELTYPE\" : \"TWPT_RGB\"," +
                "    \"ICAP_SUPPORPORTEDSIZES\" : \"TWSS_USLESLETTER\"" +
                "  }," +
                "  \"prompt_scan_more\" : true," +
                "  \"output_settings\" : [ {" +
                "    \"type\" : \"save\"," +
                "    \"format\" : \"jpg\"," +
                "    \"save_path\" : \".\\\\${TMS}${EXT}\"" +
                "  } ]" +
                "}", "select", true, true);

            List<string> files = result == null ? null : result.GetImageFiles();
            Console.WriteLine("Scanned: " + string.Join(", ", files == null ? new string[0] : files.ToArray()));
        }

        public static void scanAndUpload()
        {
            Result result = new AspriseImaging().Scan(new Request().AddOutputItem(
                new RequestOutputItem(AspriseImaging.OUTPUT_UPLOAD, AspriseImaging.FORMAT_JPG).SetUploadSetting(
                    new UploadSetting("http://asprise.com/scan/applet/upload.php?action=dump").AddPostField("title", "Test scan"))),
                "select", true, true);
            String response = result == null ? null : result.GetUploadResponse();
            Console.WriteLine("From server: \n" + response);
        }

        public static void scanAndUploadJson()
        {
            Result result = new AspriseImaging().Scan("{" +
              "  \"output_settings\" : [ {" +
              "    \"type\" : \"upload\"," +
              "    \"format\" : \"jpg\"," +
              "    \"upload_target\" : {" +
              "      \"url\" : \"http://asprise.com/scan/applet/upload.php?action=dump\"," +
              "      \"post_fields\" : {" +
              "        \"title\" : \"Test scan\"" +
              "      }" + 
              "    }" +
              "  } ]" +
              "}", "select", true, true);
            String response = result == null ? null : result.GetUploadResponse();
            Console.WriteLine("From server: \n" + response);
        }

        public static void scanToPdf()
        {
            Result result = new AspriseImaging().Scan(new Request().AddOutputItem(
                new RequestOutputItem(AspriseImaging.OUTPUT_SAVE, AspriseImaging.FORMAT_PDF)
                    .SetPdfTextLine("Scanned on ${DATETIME} by user X") // Optional text line at the bottom of the 1st page
                    .AddExifTag("DocumentName", "Scan to PDF by Asprise") // Optional PDF doc properties (metadata)
                    .SetSavePath(".\\${TMS}${EXT}")
                ).SetPromptScanMore(true) // whether to prompt user to scan more pages
             , "select", true, true);

            string pdfFile = result == null ? null : result.GetPdfFile();
            Console.WriteLine("Documents scanned as PDF: " + pdfFile);
        }

        public static void scanToPdfCcittG4AndUpload()
        {
            Result result = new AspriseImaging().Scan(new Request().AddOutputItem(
                new RequestOutputItem(AspriseImaging.OUTPUT_UPLOAD, AspriseImaging.FORMAT_PDF)
                    .SetPdfForceBlackWhite(true)
                    .SetUploadSetting(new UploadSetting("http://asprise.com/scan/applet/upload.php?action=dump")
                        .SetCookies("name=value; poweredBy=Asprise"))
                ), "select", true, true);

            String response = result == null ? null : result.GetUploadResponse();
            Console.WriteLine("From server: \n" + response);
        }

        public static void scanToPdfA()
        {
            Result result = new AspriseImaging().Scan(new Request().AddOutputItem(
                new RequestOutputItem(AspriseImaging.OUTPUT_SAVE, AspriseImaging.FORMAT_PDF)
                    .SetPdfaCompliant(true)
                    .AddExifTag(AspriseImaging.EXIF_NAME_DocumentName, "PDF/A to meet compliance requirements")
                    .SetSavePath(".\\${TMS}${EXT}")
                ), "select", true, true);
            string pdfFile = result == null ? null : result.GetPdfFile();
            Console.WriteLine("Documents scanned as PDF: " + pdfFile);
        }

        public static void scanToTiff()
        {
            Result result = new AspriseImaging().Scan(new Request().AddOutputItem(
                new RequestOutputItem(AspriseImaging.OUTPUT_SAVE, AspriseImaging.FORMAT_TIF)
                    .SetTiffCompression(AspriseImaging.TIFF_COMPRESSION_CCITT_G4)
                    .SetSavePath(".\\${TMS}${EXT}")
            ), "select", true, true);

            string tiffFile = result == null ? null : result.GetTiffFile();
            Console.WriteLine("Documents scanned as TIFF: " + tiffFile);
        }

        public static void scanToMemory()
        {
            Result result = new AspriseImaging().Scan(new Request().AddOutputItem(
                new RequestOutputItem(AspriseImaging.OUTPUT_RETURN_BASE64, AspriseImaging.FORMAT_JPG)
            ), "select", true, true);

            Console.WriteLine("Scan to memory: " + result);
        }

        public static void recognizeBarcodes()
        {
            Result result = new AspriseImaging().Scan(new Request()
                .SetRecognizeBarcodes(true)
                .AddOutputItem(new RequestOutputItem(AspriseImaging.OUTPUT_SAVE, AspriseImaging.FORMAT_JPG).SetSavePath(".\\${TMS}${EXT}")),
            "select", true, true);

            List<string> barcodes = result == null ? null : result.GetBarcodes();
            Console.WriteLine("Barcodes: " + string.Join(";\n", barcodes == null ? new string[0] : barcodes.ToArray()));
        }

        public static void recognizeBarcodesJson()
        {
            Result result = new AspriseImaging().Scan("{" +
                "  \"recognize_barcodes\" : true," +
                "  \"output_settings\" : [ {" +
                "    \"type\" : \"save\"," +
                "    \"format\" : \"jpg\"," +
                "    \"save_path\" : \".\\\\${TMS}${EXT}\"" +
                "  } ]" +
                "}", "select", true, true);

            List<string> barcodes = result == null ? null : result.GetBarcodes();
            Console.WriteLine("Barcodes: " + string.Join(";\n", barcodes == null ? new string[0] : barcodes.ToArray()));
        }

        public static void adf()
        {
            Result result = new AspriseImaging().Scan(new Request()
                .SetTwainCap(TwainConstants.CAP_FEEDERENABLED, true)
                .SetTwainCap(TwainConstants.CAP_AUTOFEED, true)
                .SetTwainCap(TwainConstants.CAP_DUPLEXENABLED, true)
                .SetDiscardBlankPages(true)
                .SetBlankPageThreshold(0.03m)
                .AddOutputItem(new RequestOutputItem(AspriseImaging.OUTPUT_SAVE, AspriseImaging.FORMAT_PDF).SetSavePath(".\\${TMS}${EXT}")),
                "select", true, true);
            string pdfFile = result == null ? null : result.GetPdfFile();
            Console.WriteLine("Documents scanned as PDF: " + pdfFile);
        }

        public static void listSources()
        {
            AspriseImaging imaging = new AspriseImaging();
            List<Source> sourcesNameOnly = imaging.ScanListSources(); // Names without capabilities

            List<Source> sourcesFullDetails = imaging.ScanListSourcesWithFullDetails(); // with caps
            foreach (Source src in sourcesFullDetails)
            {
                Console.WriteLine(src.ProductName + ": pixel type = " + 
                    src.GetCap(TwainConstants.ICAP_PIXELTYPE).GetCurrentValue());
            }

            Source defaultSource = Source.GetDefaultSource(sourcesFullDetails);
            Console.WriteLine("Default source is: " + defaultSource);

            Source source = defaultSource;
            List<Capability> caps = source.GetCaps();
            foreach (Capability cap in caps)
            {
                Console.WriteLine(cap.GetName() + ": " + cap.GetCurrentValue());
            }
        }

        public static void setGetCaps()
        {
            Source source = new AspriseImaging().GetSource("select", false, "all", false, false, "CAP_FEEDERENABLED: 1; CAP_DUPLEXENABLED: 1");
            List<Capability> caps = source.GetCaps();

            foreach (Capability cap in caps)
            {
                Console.WriteLine(cap.GetName() + ": " + cap.GetCurrentValue());
            }
        }

    }
}
