﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using asprise_imaging_api;

namespace asprise_scan_scanner_twain_wia_api
{
    public partial class SampleScanResultItemRender : UserControl
    {
        string imgFile;
        ResultImageItem imageItem;
        Image img;

        static Bitmap bitmapIconJpg = new Bitmap(Properties.Resources.icon_jpg_48);
        static Bitmap bitmapIconPdf = new Bitmap(Properties.Resources.icon_pdf_48);
        static Bitmap bitmapIconHtm = new Bitmap(Properties.Resources.icon_htm_48);

        public SampleScanResultItemRender(string imgFile, ResultImageItem imageItem) : this()
        {
            setResult(imgFile, imageItem);
        }

        public SampleScanResultItemRender(Image img, ResultImageItem imageItem)
            : this()
        {
            setResult(img, imageItem);
        }

        public SampleScanResultItemRender()
        {
            InitializeComponent();
            pictureBox.DoubleClick += buttonView_Click;
        }

        public void setResult(Image img, ResultImageItem imageItem)
        {
            this.img = img;
            this.imageItem = imageItem;
            pictureBox.Image = img;
            if (imageItem == null)
            {
                label.Text = "<N/A>";
            }
            else
            {
                label.Text = imageItem.GetImageInfoWidth() + " x " + imageItem.GetImageInfoHeight() +
                    Environment.NewLine +
                    imageItem.GetImageInfoBitDepth() + " bits" +
                    Environment.NewLine +
                    TwainConstants.getPixelTypeName(imageItem.GetImageInfoPixelType()) + " in memory";
                ;
            }
        }

        public void setResult(string imgFile, ResultImageItem imageItem)
        {
            this.imgFile = imgFile;
            this.imageItem = imageItem;
            pictureBox.Image = null;
            if (imgFile != null && imgFile.ToLower().EndsWith(".pdf"))
            {
                pictureBox.Image = bitmapIconPdf;
            }
            else if (ScanUtils.isSimpleImageFormat(imgFile))
            {
                pictureBox.Image = bitmapIconJpg;
            }
            else if(imgFile != null)
            {
                pictureBox.Image = bitmapIconHtm;
            }

            if (imageItem == null)
            {
                label.Text = "<N/A>";
            }
            else
            {
                label.Text = imageItem.GetImageInfoWidth() + " x " + imageItem.GetImageInfoHeight() +
                    Environment.NewLine +
                    imageItem.GetImageInfoBitDepth() + " bits" +
                    Environment.NewLine +
                    TwainConstants.getPixelTypeName(imageItem.GetImageInfoPixelType());
                    ;
            }

            ToolTip tooltip = new ToolTip();
            tooltip.SetToolTip(label, (imgFile == null ? "" : imgFile + Environment.NewLine) +
                (imageItem == null || imageItem.GetImageInfo() == null ? "" : imageItem.GetImageInfo().ToString()));
        }

        private void buttonView_Click(object sender, EventArgs e)
        {
            if (img == null)
            {
                ScanUtils.previewImage(imgFile);
            }
            else
            {
                Form formImg = ScanUtils.displayImageOnForm(img, this, false);
                formImg.ShowDialog();
            }
        }
    }
}
